@@ -9,7 +9,7 @@
 /*  CCOPYRIGHT */
 
 /****************************************************************************
-** $Id: application.cpp,v 1.143 2007/08/08 13:52:08 flitney Exp $
+** $Id: application.cpp,v 1.143.4.2 2007/08/12 17:08:43 flitney Exp $
 **
 ** Copyright (C) 2002 University of Oxford.  All rights reserved.
 **
@@ -498,7 +498,7 @@ void ApplicationWindow::fileAdd()
 
 void ApplicationWindow::fileOpen152(void)
 {
-  QString fn(QFileDialog::getOpenFileName(Preferences::instance()->mni152().c_str(),
+  QString fn(QFileDialog::getOpenFileName(Preferences::getInstance()->inqMni152().c_str(),
 					  "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					  this ));
 
@@ -508,7 +508,7 @@ void ApplicationWindow::fileOpen152(void)
 
 void ApplicationWindow::fileAdd152(void)
 {
-  QString fn(QFileDialog::getOpenFileName(Preferences::instance()->mni152().c_str(),
+  QString fn(QFileDialog::getOpenFileName(Preferences::getInstance()->inqMni152().c_str(),
 					  "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					  this ));
 
@@ -552,9 +552,9 @@ void ApplicationWindow::buildMenus()
   initViewMenuItems(state);
 }
 
-void ApplicationWindow::applicationProperties()
+void ApplicationWindow::filePreferences()
 {
-  //  Properties& p = PropertiesDialogImpl::getProperties(this);
+  PropertiesDialogImpl::getProperties(this);
 }
 
 void ApplicationWindow::connectControls()
