@@ -16,16 +16,25 @@
 #include <vector>
 #include <boost/shared_ptr.hpp>
 
-class Preferences
+#include <qsettings.h>
+
+class Preferences: public QSettings
 {
 public:
   typedef boost::shared_ptr<Preferences> Handle;
 
-  std::string FSLDir() const;
-  std::string mni152() const;
-  std::vector<std::string> atlasPath() const;
+  std::string inqFSLDir() const;
+  std::string inqMni152() const;
+  std::string inqAssistantPath() const;
+  std::string inqAtlasPath() const;
+  std::vector<std::string> inqAtlasPathElements() const;
 
-  static Handle instance();
+  void setFSLDir(const std::string&);
+  void setMni152(const std::string&);
+  void setAssistantPath(const std::string&);
+  void setAtlasPath(const std::string&);
+
+  static Handle getInstance();
 
 private:
   Preferences();
