@@ -94,6 +94,9 @@
 #include <vtkWindowToImageFilter.h>
 #include <vtkTIFFWriter.h>
 
+#include <vtkPolyDataConnectivityFilter.h>
+#include <vtkAppendPolyData.h>
+
 #include "vtktoolbar.h"
 #include "vtkpropertydialog.h"
 #include "meshoptionsdialog.h"
@@ -161,10 +164,10 @@ public:
   { return new InteractorCallback; }
   virtual void Execute(vtkObject* caller, unsigned long eventid, void*)
   {
-    cout << "An event!" << endl;
+    //cout << "An event!" << endl;
     switch(eventid) {
     case vtkCommand::StartInteractionEvent:
-      cout << "Start event" << endl;
+      //cout << "Start event" << endl;
       if(m_props->inqOpacity() != 1.0)
 	{
 	  cout << "Disconnect sorter" << endl;
@@ -172,7 +175,7 @@ public:
 	}
       break;
     case vtkCommand::EndInteractionEvent:
-      cout << "End event" << endl;
+      //cout << "End event" << endl;
       if(m_props->inqOpacity() != 1.0)
 	{
 	  cout << "Connect sorter" << endl;
@@ -326,7 +329,7 @@ public:
 
   ImagePipelineObject(MetaImage::Handle mi, vtkRenderer *ren): 
     m_smooth(vtkSmoothPolyDataFilter::New()),
-    m_sorter(vtkDepthSortPolyData::New()),
+//     m_sorter(vtkDepthSortPolyData::New()),
     m_normals(vtkPolyDataNormals::New()),
     m_bricon(mi->getDs()->inqBriCon()), 
     m_metaimage(mi), m_layerMapper(0),
@@ -379,7 +382,7 @@ public:
     m_bricon->detach(this);
     m_smooth->Delete();
     m_normals->Delete();
-    m_sorter->Delete();
+//     m_sorter->Delete();
   }
 
   virtual void update(const BriCon* bc) {}
@@ -396,13 +399,13 @@ public:
     return m_layerMapper;
   }
 
-  virtual void setSorting(bool sorting)
-  {
-    if(sorting)
-      m_normals->SetInput(m_smooth->GetOutput());
-    else
-      m_normals->SetInput(m_sorter->GetOutput());
-  }
+//   virtual void setSorting(bool sorting)
+//   {
+//     if(sorting)
+//       m_normals->SetInput(m_smooth->GetOutput());
+//     else
+//       m_normals->SetInput(m_sorter->GetOutput());
+//   }
 
   void Render() { m_ren->GetRenderWindow()->Render(); }
 
@@ -417,7 +420,7 @@ public:
 
 protected:
   vtkSmoothPolyDataFilter *m_smooth;
-  vtkDepthSortPolyData *m_sorter;
+//   vtkDepthSortPolyData *m_sorter;
   vtkPolyDataNormals *m_normals;
   BriCon::Handle m_bricon;
   MetaImage::Handle m_metaimage;
@@ -453,23 +456,22 @@ public:
  
     // And IsoSurface
     m_th->SetInput(m_imageData);
-    float delta=(bc->inqMax() - bc->inqMin()) / 10.0;
-    m_th->ThresholdByUpper(bc->inqMin()+delta);
-    m_th->ReplaceOutOn();
-    m_th->ReplaceInOff();
-    m_th->SetOutputScalarTypeToFloat();
+    m_th->ThresholdByUpper(bc->inqMin());
     m_th->SetOutValue(0.0);
     m_th->SetInValue(1.0);
+    m_th->ReplaceOutOn();
+    m_th->ReplaceInOn();
+    m_th->SetOutputScalarTypeToFloat();
     m_th->UpdateInformation();
 
-    vtkImageDilateErode3D *mcdil = vtkImageDilateErode3D::New();
-    mcdil->SetInput(m_th->GetOutput());
-    mcdil->SetKernelSize(2, 2, 2);
-    mcdil->SetDilateValue(1);
-    mcdil->SetErodeValue(0);
+//     vtkImageDilateErode3D *mcdil = vtkImageDilateErode3D::New();
+//     mcdil->SetInput(m_th->GetOutput());
+//     mcdil->SetKernelSize(2, 2, 2);
+//     mcdil->SetDilateValue(1);
+//     mcdil->SetErodeValue(0);
 	  
     vtkMarchingCubes *mclayer = vtkMarchingCubes::New();
-    mclayer->SetInput(mcdil->GetOutput());
+    mclayer->SetInput(m_th->GetOutput());
     mclayer->SetValue(0,0.5);
     mclayer->ComputeNormalsOn();
 
@@ -480,7 +482,7 @@ public:
     mcdecim->BoundaryVertexDeletionOn();
 
     m_smooth->SetInput(mcdecim->GetOutput());
-    m_smooth->SetNumberOfIterations(20);
+    m_smooth->SetNumberOfIterations(5);
     m_smooth->SetFeatureAngle(150);
     m_smooth->SetFeatureEdgeSmoothing(true);
     m_smooth->SetBoundarySmoothing(true);
@@ -492,10 +494,10 @@ public:
     m_normals->NonManifoldTraversalOff();
     m_normals->SetFeatureAngle(150);
 
-    m_sorter->SetInput(m_smooth->GetOutput());
-    m_sorter->SetCamera(ren->GetActiveCamera());
-    m_sorter->SortScalarsOn();
-    m_sorter->SetDirectionToBackToFront();
+//     m_sorter->SetInput(m_smooth->GetOutput());
+//     m_sorter->SetCamera(ren->GetActiveCamera());
+//     m_sorter->SortScalarsOn();
+//     m_sorter->SetDirectionToBackToFront();
   }
 
   virtual vtkMapper *getLayerMapper()
@@ -514,8 +516,7 @@ public:
 
   virtual void update(const BriCon* bc)
   {
-    float delta=(bc->inqMax() - bc->inqMin()) / 10.0;
-    m_th->ThresholdByUpper(bc->inqMin()+delta);    
+    m_th->ThresholdByUpper(bc->inqMin());    
     m_imageLut->SetRange(bc->inqMin(), bc->inqMax());
     Render();
   }
@@ -584,10 +585,10 @@ public:
     m_normals->NonManifoldTraversalOff();
     m_normals->SetFeatureAngle(150);
     
-    m_sorter->SetInput(m_smooth->GetOutput());
-    m_sorter->SetCamera(ren->GetActiveCamera());
-    m_sorter->SortScalarsOn();
-    m_sorter->SetDirectionToBackToFront();
+//     m_sorter->SetInput(m_smooth->GetOutput());
+//     m_sorter->SetCamera(ren->GetActiveCamera());
+//     m_sorter->SortScalarsOn();
+//     m_sorter->SetDirectionToBackToFront();
   }
 
   vtkImageData* GetThreshOutput() { return m_th->GetOutput(); }
@@ -645,10 +646,10 @@ public:
     m_normals->NonManifoldTraversalOff();
     m_normals->SetFeatureAngle(props.inqFeatureAngle());
 
-    m_sorter->SetInput(m_smooth->GetOutput());
-    m_sorter->SortScalarsOn();
-    m_sorter->SetCamera(ren->GetActiveCamera());
-    m_sorter->SetDirectionToBackToFront();
+//     m_sorter->SetInput(m_smooth->GetOutput());
+//     m_sorter->SortScalarsOn();
+//     m_sorter->SetCamera(ren->GetActiveCamera());
+//     m_sorter->SetDirectionToBackToFront();
 
     connect->Delete();
     decim->Delete();
@@ -1091,8 +1092,11 @@ void VTKWidget::addMesh()
 
 void VTKWidget::meshOptions()
 {
-  m_impl->m_meshOptions.populateMeshList(m_impl->m_meshes);
-  m_impl->m_meshOptions.show();
+  if(m_impl->m_meshes.size())
+    {
+      m_impl->m_meshOptions.populateMeshList(m_impl->m_meshes);
+      m_impl->m_meshOptions.show();
+    }
 }
 
 void VTKWidget::update(const VTKProperties* p)
@@ -1133,7 +1137,7 @@ void VTKWidget::update(const OverlayList *ol, OverlayListMsg msg)
   vtkPolyData *ds = m_impl->m_mainImage->GetSurface();
   if(m_impl->m_props.inqClipping())
     ds = m_impl->m_clipper->GetOutput();
-  m_impl->m_sorter->SetInput(ds);
+  m_impl->m_sorter->SetInput(ds); // AddInputConnection()
   if(m_impl->m_ol->getMainMetaImage()->inqTransparency() != 1.0)
     m_impl->m_surfMapper->SetInput(m_impl->m_sorter->GetOutput());
   else
